import 'dart:convert';

/// Flutter package imports
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'package:syncfusion_flutter_maps/maps.dart';

class TestMapPage extends StatefulWidget {
  @override
  _TestMapPageState createState() => _TestMapPageState();
}

class _TestMapPageState extends State<TestMapPage> {
  late MapShapeSource _sublayerSource;
  late List<Model> data;
  late MapShapeSource dataSource;
  late MapShapeSource subSource;

  @override
  void initState() {
    super.initState();

    data = <Model>[
      Model('Asia', 50, '44,579,000 sq. km.'),
      Model('Africa', 54, '30,370,000 sq. km.'),
      Model('Europe', 51, '10,180,000 sq. km.'),
      Model('North America', 23, '24,709,000 sq. km.'),
      Model('South America', 12, '17,840,000 sq. km.'),
      Model('Australia', 14, '8,600,000 sq. km.'),
    ];

    dataSource = MapShapeSource.asset(
      "assets/world_map.json",
      shapeDataField: "continent",
      dataCount: data.length,
      primaryValueMapper: (int index) => data[index].continent,
      bubbleSizeMapper: (int index) => data[index].countriesCount,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Padding(
        padding: const EdgeInsets.only(left: 15, right: 15),
        child: SfMaps(
          layers: [
            MapTileLayer(
              urlTemplate: 'https://tile.openstreetmap.org/{z}/{x}/{y}.png',
              sublayers: [
                MapShapeSublayer(
                  color: Colors.transparent,
                  strokeColor: Colors.transparent,
                  source: dataSource,
                  bubbleTooltipBuilder: (BuildContext context, int index) {
                    return Container(
                        height: 80,
                        width: 200,
                        child: Padding(
                          padding: EdgeInsets.all(10),
                          child: Text(
                            'Continent : ' +
                                data[index].continent +
                                '\nTotal Countries : ' +
                                data[index].countriesCount.toStringAsFixed(0),
                          ),
                        ));
                  },
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}

class Model {
  const Model(this.continent, this.countriesCount, this.area);

  final String continent;
  final double countriesCount;
  final String area;
}
